@@ -1,9 +1,11 @@
 __all__ = ['Client', 'ErrorMessage', 'ReverseIpApiError', 'ApiAuthError',
            'HttpApiError', 'EmptyApiKeyError', 'ParameterError',
-           'ResponseError', 'BadRequestError', 'UnparsableApiResponse',
+           'ResponseError', 'BadRequestError', 'UnparsableApiResponseError',
            'ApiRequester', 'Result', 'Record']
 
 from .client import Client
 from .net.http import ApiRequester
 from .models.response import ErrorMessage, Result, Record
-from .exceptions.error import *
+from .exceptions.error import ReverseIpApiError, ParameterError, \
+    EmptyApiKeyError, ResponseError, UnparsableApiResponseError, \
+    ApiAuthError, BadRequestError, HttpApiError
